@@ -1,6 +1,6 @@
 #! /bin/sh
 #simple sync of the rescue filesystem, based on inotifywait
- 
+
 PRG=$0
 
 function usage ()
@@ -35,7 +35,7 @@ do
        --type)		    MODIFICATION_TYPE="$2";shift 2;;
 	   --help)        	usage;shift;;
        -h)        	usage;shift;;
-       --) 		shift;break;;       
+       --) 		shift;break;;
     esac
 
 done
@@ -83,10 +83,11 @@ function loop()
   previous_file=
   TIMEOUT=
   while [ true ]
-  do	
+  do
 	next_file=$(read $TIMEOUT; echo $REPLY)
 	if [ -z "$next_file" ] ; then
 		TIMEOUT=
+		sleep 0.1
     else
         echo "file changed: $next_file"
 		TIMEOUT=$TIMEOUT_RELOAD
@@ -94,14 +95,14 @@ function loop()
 	if [ "$next_file" != "$previous_file" ] ; then
 	  [ ! -z $previous_file ] && do_copy $previous_file
 	fi
-	previous_file=$next_file  
+	previous_file=$next_file
   done
 }
 
 function loopDir()
 {
-   while read path action file; 
-   do         
+   while read path action file;
+   do
       echo "The file '$file' changed in directory '$path' via '$action'";
       if [ ! -z $file ] ; then
          if [ "$action" != "DELETE" ] ; then
@@ -109,7 +110,7 @@ function loopDir()
          else
             do_remove $path$file
          fi
-      fi       
+      fi
    done
 }
 
@@ -137,13 +138,14 @@ function start_inotify_rename()
    done
 }
 
-# inotify expects the file to exist. If it doesn't, then we create it.
-# do not create empty ssu.conf, isu can't manage it!
-for i in $LIST ; do ([ ! -e $i ] && [ "$i" != "/acterna/storage/share/ssu.conf" ] && touch $i) ; done
-
-## inotify expects the file to exist. If it doesn't, then we remove it from the list
-#for i in $LIST ; do [ -e $i ] && NEWLIST="$i $NEWLIST" ; done
-#LIST=$NEWLIST
+if [[ "$MODIFICATION_TYPE" == "updateDir" ]]; then
+	# no touch on folder, we create it
+	for i in $LIST ; do ([ ! -e $i ] && mkdir $i) ; done
+else
+	# inotify expects the file to exist. If it doesn't, then we create it.
+	# do not create empty ssu.conf, isu can't manage it!
+	for i in $LIST ; do ([ ! -e $i ] && [ "$i" != "/acterna/storage/share/ssu.conf" ] && touch $i) ; done
+fi
 
 case "$MODIFICATION_TYPE" in
 	update)
@@ -155,8 +157,8 @@ case "$MODIFICATION_TYPE" in
 		start_inotify_rename
 		;;
 	updateDir)
-        echo "inotifywait --exclude \.part -m -e ATTRIB -e MODIFY -e DELETE $LIST | loopDir"
-        inotifywait --exclude \.part -m -e ATTRIB -e MODIFY -e DELETE $LIST | loopDir
+        echo "inotifywait --exclude \.part -m -e ATTRIB,MODIFY,DELETE,CREATE $LIST | loopDir"
+        inotifywait --exclude \.part -m -e ATTRIB,MODIFY,DELETE,CREATE $LIST | loopDir
 		;;
 	*)
 		echo $"Usage: $0 {update|rename|updateDir} {files list}"
