@@ -120,6 +120,7 @@ class SMTOtuApi
     const RES_DIFF = 'DIFF';
     const RES_NO = 'NO';
     const RES_NONE = 'NONE';
+    const RES_WDM = 'WDM';
     const RES_UNKNOWN = '???';
     const RES_UNKNOWN_AF = 'Unknown AF';
     const RES_YES = 'YES';
@@ -900,7 +901,7 @@ class SMTOtuApi
     const CMD_get_ip = 'OTU:SYSTEM:COM:IP? %s';
     //ETH0
     const CMD_get_subnet = 'OTU:SYSTEM:COM:SUBNET? %s';
-    const CMD_get_gateway = 'OTU:SYSTEM:COM:GATEWAY?';
+    const CMD_get_gateway = 'OTU:SYSTEM:COM:NGATEWAY? %s';
     const CMD_get_dns = 'OTU:SYSTEM:COM:DNS?';
     /**
      * TSC1 or TSC2
@@ -922,18 +923,26 @@ class SMTOtuApi
     	return sprintf( self::CMD_get_onms_name, $index );
     } 
     
+    const CMD_get_network_Interface_Count = 'OTU:SYSTEM:COM:NBINterface?';
     /**
      * LOC,FIX,DHCP,DYN
      */
-    const CMD_get_otu_mode = 'OTU:SYST:COM:MOD?'; //LOC,FIX,DHCP,DYN
+    const CMD_get_otu_mode = 'OTU:SYST:COM:NMODE? %s'; //ETH0/ETH1
+    
+    const CMD_get_mtu = 'OTU:SYST:COM:MTU? %s';// ETH0/ETH1
+    const CMD_set_mtu = 'OTU:SYST:COM:MTU %s,%d';// ETH0/ETH1
+    
+    const CMD_get_autoneg = 'OTU:SYST:COM:NEGO? %s';// ETH0/ETH1
+    const CMD_set_autoneg = 'OTU:SYST:COM:NEGO %s,%s,%s';// ETH0/ETH1, ,
+    
     /**
      * LOC,FIX,DHCP or DYN
      */    
-    const CMD_set_otu_mode = 'OTU:SYSTEM:COM:MODE %s';
+    const CMD_set_otu_mode = 'OTU:SYSTEM:COM:NMODE %s,%s';
     const CMD_get_backup_route = 'OTU:SYSTEM:COM:BACKUP:GATE?';
-    const CMD_set_ip = 'OTU:SYSTEM:COM:IP ETH0,%d,%d,%d,%d';//10,33,16,192
-    const CMD_set_subnet = 'OTU:SYSTEM:COM:SUBNET ETH0,%d,%d,%d,%d';//255,255,252,0
-    const CMD_set_gateway = 'OTU:SYSTEM:COM:GATEWAY %d,%d,%d,%d';
+    const CMD_set_ip = 'OTU:SYSTEM:COM:IP %s,%d,%d,%d,%d';//10,33,16,192
+    const CMD_set_subnet = 'OTU:SYSTEM:COM:SUBNET %s,%d,%d,%d,%d';//255,255,252,0
+    const CMD_set_gateway = 'OTU:SYSTEM:COM:NGATEWAY %s,%d,%d,%d,%d';
     const CMD_set_dns = 'OTU:SYSTEM:COM:DNS %d,%d,%d,%d';
     /**
      * TSC1 or TSC2 //@IP1 //@IP2 // @IP3
@@ -947,20 +956,24 @@ class SMTOtuApi
 //     const CMD_set_tsc_on = 'OTU:TSC:ON %s';
 
     //IPV6
-    const CMD_get_ipv6 = 'OTU:SYSTEM:COM:IPV6:IP? ETH0';
-    const CMD_get_gatewayv6 = 'OTU:SYSTEM:COM:IPV6:GATEWAY?';
+    const CMD_get_ipv6 = 'OTU:SYSTEM:COM:IPV6:IP? %s';
+    const CMD_get_gatewayv6 = 'OTU:SYSTEM:COM:IPV6:NGATEWAY? %s';
     const CMD_get_dnsv6 = 'OTU:SYSTEM:COM:IPV6:DNS?';
-    const CMD_get_linkipv6 = 'OTU:SYSTEM:COM:IPV6:LINKIP? ETH0';
+    const CMD_get_linkipv6 = 'OTU:SYSTEM:COM:IPV6:LINKIP? %s';
     const CMD_get_sitev6 = 'OTU:SYSTEM:COM:IPV6:SITE?';
-    const CMD_set_ipv6 = 'OTU:SYSTEM:COM:IPV6:IP ETH0,"%s"';
-    const CMD_set_gatewayv6 = 'OTU:SYSTEM:COM:IPV6:GATEWAY "%s"';
+    const CMD_set_ipv6 = 'OTU:SYSTEM:COM:IPV6:IP %s,"%s"';
+    const CMD_set_gatewayv6 = 'OTU:SYSTEM:COM:IPV6:NGATEWAY %s,"%s"';
     const CMD_set_dnsv6 = 'OTU:SYSTEM:COM:IPV6:DNS "%s"';
     const CMD_set_sitev6 = 'OTU:SYSTEM:COM:IPV6:SITE "%s"';
-    const CMD_get_otu_mode_ipv6 = 'OTU:SYSTEM:COM:IPV6:MODE?'; //FIX,DHCP,OFF
+    const CMD_get_otu_mode_ipv6 = 'OTU:SYSTEM:COM:IPV6:NMODE? %s';
+    
+    const CMD_set_ipv6_prefix = 'OTU:SYSTEM:COM:IPV6:NPRE %s,%d';
+    const CMD_get_ipv6_prefix = 'OTU:SYSTEM:COM:IPV6:NPRE? %s';
+
     /**
      * FIX,DHCP or OFF
      */
-    const CMD_set_otu_mode_ipv6 = 'OTU:SYSTEM:COM:IPV6:MODE %s';
+    const CMD_set_otu_mode_ipv6 = 'OTU:SYSTEM:COM:IPV6:NMODE %s,%s';
     
     //OTAU
     const CMD_add_otau = 'OTU:SWITCH:CONFIG:ADD? %s,"%s","%s"'; //device:OTU,IPR / GLOB switch string / rotau address ip
@@ -1006,6 +1019,7 @@ class SMTOtuApi
     //SWITCH MOLEX
     const CMD_get_switch_molex_idn = 'OTU:SWITCH:MOLEX:IDN? %d';
     const CMD_get_switch_molex_available = 'OTU:SWITCH:MOLEX:AVAIlable?'; //TRUE/FALSE
+    const CMD_get_switch_uos_available = 'OTU:SWITCH:UOSP:AVAIlable?'; //TRUE/FALSE
     const CMD_get_switch_config_type = 'OTU:SWITCH:CONFIG:TYPE? %d'; //OSX_JDSU, MOLEX
     const CMD_Has_Internal_Switch_License = 'OTU:SWITCH:LIC:INTValid?';
     const CMD_Get_Internal_Switch_Total_Ports = 'OTU:SWITCH:CONFIG:INTOutputs?';
@@ -1030,6 +1044,15 @@ class SMTOtuApi
     const CMD_switch_config_add_chaine_ROTAU = 'OTU:SWITCH:CONFIG:NROTAUADD? %s,"%s","%s"';// IP_ROTAU, String switch code, String IP
     const CMD_switch_detect_remove_chaine_ROTAU = 'OTU:SWITCH:DETECT:IPROTAU:NDEL "%s"';//String IP ROTAU
     
+    //****************
+    // DMUX
+    //****************
+    const CMD_get_dmux_list = 'OTU:WDM:LISTe?';
+    const CMD_get_dmux = 'OTU:WDM:GET? %d';// 1 DMUX position
+    const CMD_remove_dmux = 'OTU:WDM:DEL %d';// 1 DMUX position
+    const CMD_add_dmux = 'OTU:WDM:ADD? "%s",%d,%s';// 1 DMUX position, Name, Outputs, Channel
+    const CMD_update_dmux = 'OTU:WDM:CHANGE %d,"%s",%d,%s';// 1 DMUX position, Name, Outputs, Channel
+    
     //****************
     //* measurement
     //***************
@@ -2378,6 +2401,7 @@ class SMTOtuApi
      */
     const CMD_get_OTU_LICENSE = "ISU:LIC:LIST? \"OTU\"";
     const CMD_get_Sensing_LICENSE = "ISU:LIC:LIST? \"Sensing\"";
+    const CMD_get_Otdr_LICENSE = "ISU:LIC:LIST? \"Otdr\"";
     const CMD_get_SAA_LICENSE = "ISU:LIC:LIST? \"Anywhere\"";
     const CMD_get_OTAU_LICENSE = "ISU:LIC:LIST? \"Otau\"";
     
@@ -2419,6 +2443,16 @@ class SMTOtuApi
     	return self::CMD_get_SAA_LICENSE;
     }
     
+    /**
+     * WARNING ISU COMMAND
+     *
+     * @return string
+     */
+    static function getOtdrLicensesFromIsu()
+    {
+        return self::CMD_get_Otdr_LICENSE;
+    }
+    
     const CMD_isu_is_license_status = "PROCESS:LICENSE:STATUS? \"OTU\",\"%s\"";
     /**
      * WARNING ISU COMMAND
@@ -2526,6 +2560,11 @@ class SMTOtuApi
         return self::CMD_create_ufom_archive;
     }
     
+    /**
+     *
+     */
+    const CMD_upgrade_UOS = 'OTU:SWITCH:DEBUG:UOSP:UPGRADE %d';
+    
     ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     //
     // API
