@@ -1,10 +1,11 @@
 <?php
 define("MSG_BAD_CREDENTIALS","提供的凭证 (登陆名或密码) 是无效的。");
+define("MSG_BAD_DMUX","无法添加 Dmux %s，网格 %s 和输出端口 %d");
 define("MSG_BAD_THRESHOLD_VALUE","对于区域： %s 为无效的阈值 %s");
 define("MSG_BAD_ROTAU_IP","无法使用IP地址％s连接到ROTAU");
 define("MSG_CHINESE","中文");
 define("MSG_CONNECTION","连接");
-define("MSG_COPYRIGHT_SHORT","版权 © 2022 VIAVI。 版权所有。");
+define("MSG_COPYRIGHT_SHORT","版权 © 2023 VIAVI。 版权所有。");
 define("MSG_ENGLISH","English");
 define("MSG_ERROR_ADD_LOCALISATION_ERROR","添加本地化出错"); 
 define("MSG_ERROR_ALARM_UNDEFINED","未定义的警报");
@@ -254,6 +255,7 @@ define("FIBER_BREAK","纤维断裂");
 define("SPLICE_ATTENUATION","接头或APC跳线上的光纤弯曲");
 define("CONNECTOR_ATTENUATION","跳线弯曲，脏，松");
 define("FIBER_ATTENUATION","纤维弯曲");
+define("NEW_REFERENCE_REQUIRED","更换光纤：需要新的参考");
 define("UNKNOW_ALARM","未知的告警");
 define("UNKNOWN_CAUSE","未知的原因");
 ?>
