@@ -1,10 +1,11 @@
 <?php
 define("MSG_BAD_CREDENTIALS","The supplied credentials (login or password) are invalid.");
+define("MSG_BAD_DMUX","Cannot add Dmux %s, with grid %s and output ports %d");
 define("MSG_BAD_THRESHOLD_VALUE","Invalid threshold value %s for field: %s");
 define("MSG_BAD_ROTAU_IP","Cannot connect to ROTAU with Ip address %s");
 define("MSG_CHINESE","中文");
 define("MSG_CONNECTION","Connect");
-define("MSG_COPYRIGHT_SHORT","Copyright © 2022 VIAVI. All rights reserved.");
+define("MSG_COPYRIGHT_SHORT","Copyright © 2023 VIAVI. All rights reserved.");
 define("MSG_ENGLISH","English");
 define("MSG_ERROR_ADD_LOCALISATION_ERROR","Add localisation error"); 
 define("MSG_ERROR_ALARM_UNDEFINED","Undefined alarm");
@@ -254,6 +255,7 @@ define("FIBER_BREAK","Fiber Break");
 define("SPLICE_ATTENUATION","Fiber bending on splice or on APC patchcord");
 define("CONNECTOR_ATTENUATION","Patchcord bending, dirty, loose");
 define("FIBER_ATTENUATION","Fiber bending");
+define("NEW_REFERENCE_REQUIRED","Fiber change: New reference required");
 define("UNKNOW_ALARM","Unknown alarm");
 define("UNKNOWN_CAUSE","Unknown cause");
 ?>
