@@ -61,7 +61,7 @@ class SMTApiPortService extends SMTService implements SMTIService
 			$this->getContext()->getLogger()->traceException($e);
 			SMTHttpResponse::handleApiError( $this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, SMTApiDto::FAILURE, 'Failed to retrieve ports count');
 		}
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $portDto->getJsonData();
 	}
@@ -137,7 +137,7 @@ class SMTApiPortService extends SMTService implements SMTIService
 				SMTHttpResponse::handleApiError( $this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, $testStatusDto->getStatus(), $message);
 			}
 		}
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $testStatusDto->getJsonData();
 	}
@@ -207,7 +207,7 @@ class SMTApiPortService extends SMTService implements SMTIService
 			$this->getContext()->getLogger()->traceException($e);
 			SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::BAD_REQUEST, SMTApiDto::FAILURE, 'No monitoring on port '.$portNumber);
 		}
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $linkDto->getJsonData();
 	}
@@ -341,7 +341,7 @@ class SMTApiPortService extends SMTService implements SMTIService
 // 			$this->getContext()->getLogger()->traceException($e);
 // 			SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, SMTApiDto::FAILURE, 'Failed to retrieve ports $start -> $end');
 // 		}
-		$this->getContext()->closeSession();
+        $this->getContext()->closeSession('api');
 		return $linkListDto->getJsonData();
 	}	
 	
@@ -403,7 +403,7 @@ class SMTApiPortService extends SMTService implements SMTIService
 			$this->getContext()->getLogger()->traceException($e);
 			SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::BAD_REQUEST, SMTApiDto::FAILURE, 'No monitoring on port '.$portNumber);
 		}
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $portAlarmStatusDto->getJsonData();
 	}
@@ -488,7 +488,7 @@ class SMTApiPortService extends SMTService implements SMTIService
 			SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::INTERNAL_SERVER_ERROR, SMTApiDto::FAILURE, 'Failed to retrieve alarms status for ports $start -> $end');
 		}
 		
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $portAlarmStatusListDto->getJsonData();
 	
@@ -517,7 +517,7 @@ class SMTApiPortService extends SMTService implements SMTIService
 			$this->getContext()->getLogger()->traceException($e);
 			SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::BAD_REQUEST, SMTApiDto::FAILURE, 'No optical alarm on port '.$portNumber);
 		}
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $statusDto->getJsonData();
 	}
@@ -544,7 +544,7 @@ class SMTApiPortService extends SMTService implements SMTIService
 			$this->getContext()->getLogger()->traceException($e);
 			SMTHttpResponse::handleApiError($this->getContext(), SMTRestException::BAD_REQUEST, SMTApiDto::FAILURE, 'failed to clear alarm on port '.$portNumber);
 		}
-		$this->getContext()->closeSession();
+		$this->getContext()->closeSession('api');
 		
 		return $statusDto->getJsonData();
 	}
