@@ -149,7 +149,7 @@ class SMTEthernetService extends SMTService implements SMTIService
     	{
     	    $ethernet = new SMTEthernet();
     	    $ethernet->setContext( $this->getContext() );
-    	    $ipv4 = $ethernet->getIpv4Config();
+    	    $ipv4 = $ethernet->getIpv4Config('ETH0');
     	}
     	catch ( \Exception $e )
     	{
@@ -172,7 +172,7 @@ class SMTEthernetService extends SMTService implements SMTIService
     	{
     	    $ethernet = new SMTEthernet();
     	    $ethernet->setContext( $this->getContext() );
-    	    $ipv6 = $ethernet->getIpv6Config();
+    	    $ipv6 = $ethernet->getIpv6Config('ETH0');
     	}
     	catch ( \Exception $e )
     	{
@@ -180,7 +180,53 @@ class SMTEthernetService extends SMTService implements SMTIService
     	}
     
     	return $ipv6->getJsonData();
-    }      
+    }
+    
+    /**
+     *
+     * @url GET /ipv4backup
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires user}
+     */
+    function getIpv4BackupConfig()
+    {
+        try
+        {
+            $ethernet = new SMTEthernet();
+            $ethernet->setContext( $this->getContext() );
+            $ipv4 = $ethernet->getIpv4Config('ETH1');
+        }
+        catch ( \Exception $e )
+        {
+            $this->handleException($e);
+        }
+        
+        return $ipv4 != NULL ? $ipv4->getJsonData() : NULL;
+    }
+    
+    /**
+     *
+     * @url GET /ipv6backup
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires user}
+     */
+    function getIpv6BackupConfig()
+    {
+        try
+        {
+            $ethernet = new SMTEthernet();
+            $ethernet->setContext( $this->getContext() );
+            $ipv6 = $ethernet->getIpv6Config('ETH1');
+        }
+        catch ( \Exception $e )
+        {
+            $this->handleException($e);
+        }
+        
+        return $ipv6 != NULL? $ipv6->getJsonData() : NULL;
+    }
     
     /**
      * Full json request data are by default stored in an array in parameter Default::$fullRequestDataName='request_Data'  
@@ -197,14 +243,38 @@ class SMTEthernetService extends SMTService implements SMTIService
     	    
     	    $ethernet = new SMTEthernet();
     	    $ethernet->setContext( $this->getContext() );
-    	    $ethernet->setIpv4Config($ipv4); 
+    	    $ethernet->setIpv4Config($ipv4, 'ETH0'); 
     	}
     	catch ( \Exception $e )
     	{
     		$this->handleException($e);
     	}
     	return $ipv4->getJsonData();
-    }    
+    }
+    
+    /**
+     * Full json request data are by default stored in an array in parameter Default::$fullRequestDataName='request_Data'
+     *
+     * @url POST /ipv4backup
+     * @access protected
+     * @class SMTAccessControl {@requires install}
+     */
+    function setIpv4BackupConfig( $request_data )
+    {
+        try
+        {
+            $ipv4 = SMTIpv4Dto::getInstance( $request_data );
+            
+            $ethernet = new SMTEthernet();
+            $ethernet->setContext( $this->getContext() );
+            $ethernet->setIpv4Config($ipv4, 'ETH1');
+        }
+        catch ( \Exception $e )
+        {
+            $this->handleException($e);
+        }
+        return $ipv4->getJsonData();
+    }
     
     /**
      * Full json request data are by default stored in an array in parameter Default::$fullRequestDataName='request_Data'
@@ -221,7 +291,7 @@ class SMTEthernetService extends SMTService implements SMTIService
     	    
     	    $ethernet = new SMTEthernet();
     	    $ethernet->setContext( $this->getContext() );
-    	    $ethernet->setIpv6Config($ipv6); 
+    	    $ethernet->setIpv6Config($ipv6,'ETH0'); 
     
     	}
     	catch ( \Exception $e )
@@ -231,6 +301,31 @@ class SMTEthernetService extends SMTService implements SMTIService
     	return $ipv6->getJsonData();
     }
     
+    /**
+     * Full json request data are by default stored in an array in parameter Default::$fullRequestDataName='request_Data'
+     *
+     * @url POST /ipv6backup
+     * @access protected
+     * @class SMTAccessControl {@requires install}
+     */
+    function setIpv6BackupConfig( $request_data )
+    {
+        try
+        {
+            $ipv6 = SMTIpv4Dto::getInstance( $request_data );
+            
+            $ethernet = new SMTEthernet();
+            $ethernet->setContext( $this->getContext() );
+            $ethernet->setIpv6Config($ipv6,'ETH1');
+            
+        }
+        catch ( \Exception $e )
+        {
+            $this->handleException($e);
+        }
+        return $ipv6->getJsonData();
+    }
+    
     /**
      *
      * @url GET /
@@ -265,8 +360,8 @@ class SMTEthernetService extends SMTService implements SMTIService
     	try
     	{
     	    $hostName = $this->getHostName();
-    	    $ipv4 = $ethernet->getIpv4Config();   
-    	    $ipv6 = $ethernet->getIpv6Config();
+    	    $ipv4 = $ethernet->getIpv4Config('ETH0');
+    	    $ipv6 = $ethernet->getIpv6Config('ETH0');
     	    $ethernetConfig = new SMTEthernetDto();
     	    $ethernetConfig->setFirewallMode($firewallMode);
     	    $ethernetConfig->setEnhancedSecurity($enhancedSecurity);
@@ -277,13 +372,35 @@ class SMTEthernetService extends SMTService implements SMTIService
     	    {
     	    	try
     	    	{
-    	    		$ethernet->getBackupRoute($ethernetConfig);
+    	    		$ethernet->getBackupRoute8kv2($ethernetConfig);
     	    	}
     	    	catch(\Exception $e)
     	    	{
     	    		$this->getContext()->traceException($e);
     	    	}
     	    }
+    	    else if ( SMTOtuType::isOTH() )
+    	    {
+    	        try
+    	        {
+    	            $hasBackupInterface = ( intval($this->sendReceive( SMTOtuApi::CMD_get_network_Interface_Count ) ) > 1 );
+    	            $ethernetConfig->set_Second_ETH_Active($hasBackupInterface);
+        	        $ipv4 = $ethernet->getIpv4Config('ETH1');
+        	        if ($ipv4 != NULL)
+        	        {
+        	           $ethernetConfig->setIpv4Backup($ipv4);    
+        	        }
+        	        $ipv6 = $ethernet->getIpv6Config('ETH1');
+        	        if ($ipv6 != NULL )
+        	        {
+        	            $ethernetConfig->setIpv6Backup($ipv6); 
+        	        }    	        
+    	        }
+        	    catch(\Exception $e)
+        	    {
+        	        $this->getContext()->traceException($e);
+        	    }
+    	    }
     	}
     	catch ( \Exception $e )
     	{
@@ -351,11 +468,11 @@ class SMTEthernetService extends SMTService implements SMTIService
 	        $this->getContext()->traceException($e);
 	    }
 	    //backup route uniquement en mode ONMSi et sur OTU8kv2
-	    if ( SMTOtuType::isOtu8KV2() && SMTOtuMode::isONMSi() )
+	    if ( SMTOtuMode::isONMSi() && SMTOtuType::isOtu8KV2() )
 	    {
 	    	try
 	    	{
-	    		$ethernet->setBackupRoute($ethernetConfig->getBackupRouteActive());
+	    	    $ethernet->setBackupRoute8kv2($ethernetConfig->getBackupRouteActive());
 	    	}
 	    	catch(\Exception $e)
 	    	{
@@ -369,11 +486,23 @@ class SMTEthernetService extends SMTService implements SMTIService
     	    if ( $ethernetConfig->isReboot() )
     	    {
     	        $this->setHostName( $ethernetConfig->getHostName() );
-    	        $ethernet->setIpv4Config( $ethernetConfig->getIpv4() );
-    	        $ethernet->setIpv6Config( $ethernetConfig->getIpv6() );    	   
-
+    	        $ethernet->setIpv4Config( $ethernetConfig->getIpv4(), 'ETH0' );
+    	        $ethernet->setIpv6Config( $ethernetConfig->getIpv6(), 'ETH0' );
+    	        
+    	        if ( SMTOtuType::isOTH() && $ethernetConfig->get_Second_ETH_Active() )
+    	        {
+        	        try 
+        	        {
+        	            $ethernet->setIpv4Config( $ethernetConfig->getIpv4Backup(), 'ETH1' );
+        	            $ethernet->setIpv6Config( $ethernetConfig->getIpv6Backup(), 'ETH1' );
+        	        } 
+        	        catch (\Exception $ex) 
+        	        {
+        	            $this->getContext()->traceException($ex);
+        	        }
+    	        }
         	    //Reboot the OTU to apply the new configuration
-        	    $this->send( sprintf( SMTOtuApi::CMD_system_reboot ) );  
+        	    $this->send( sprintf( SMTOtuApi::CMD_system_reboot ) );
 
     	        $this->getContext()->setOTUReboot();
     	    }
@@ -389,10 +518,10 @@ class SMTEthernetService extends SMTService implements SMTIService
     	        	$this->getContext()->traceException($e);
     	        }
     	        
-        	    $firewallMode = $this->getFirewallMode();        	    
+        	    $firewallMode = $this->getFirewallMode();
         	    $hostName = $this->getHostName();
-        	    $ipv4 = $ethernet->getIpv4Config();   
-        	    $ipv6 = $ethernet->getIpv6Config();
+        	    $ipv4 = $ethernet->getIpv4Config('ETHO');
+        	    $ipv6 = $ethernet->getIpv6Config('ETHO');
         	    $ethernetConfig->setHostName($hostName);
         	    $ethernetConfig->setFirewallMode($firewallMode);
         	    $ethernetConfig->setEnhancedSecurity($enhancedSecurity);
@@ -402,13 +531,36 @@ class SMTEthernetService extends SMTService implements SMTIService
         	    {
         	    	try
         	    	{
-        	    		$ethernet->getBackupRoute($ethernetConfig);
+        	    	    $ethernet->getBackupRoute8kv2($ethernetConfig);
         	    	}
         	    	catch(\Exception $e)
         	    	{
         	    		$this->getContext()->traceException($e);
         	    	}
         	    }
+        	    else if ( SMTOtuType::isOTH() )
+        	    {
+        	        try
+        	        {
+        	            $ipv4 = $ethernet->getIpv4Config('ETH1');
+        	            if ($ipv4 != NULL)
+        	            {
+        	                $ethernetConfig->setIpv4Backup($ipv4);
+        	                $ethernetConfig->set_Second_ETH_Active(TRUE);
+        	                
+        	                $ipv6 = $ethernet->getIpv6Config('ETH1');
+        	                if ($ipv6 != NULL )
+        	                {
+        	                    $ethernetConfig->setIpv6Backup($ipv6);
+        	                }
+        	            }
+        	        }
+        	        catch(\Exception $e)
+        	        {
+        	            $this->getContext()->traceException($e);
+        	        }
+        	    }
+        	    
     	    }
     	}
     	catch ( \Exception $e )
