@@ -184,7 +184,7 @@ class SMTSmartOtuSettingsService extends SMTService implements SMTIService
         	$setup->setOtuTypeLabel( trim($otuType) );
         	$setup->setOtuType( SMTOtuType::getOtuType() );
         	
-        	if (SMTOtuType::isOtu8KV2() || SMTOtuType::isMts8KV2())
+        	if (SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2() || SMTOtuType::isMts8KV2())
         	{
         		if ( strcasecmp( trim( $this->sendReceive( SMTOtuApi::getModuleName( SMTModuleDto::MOD3 ) )," \t\n\r\0\"" ), SMTOtuApi::RES_NONE ) != 0 )
             	{
@@ -203,7 +203,7 @@ class SMTSmartOtuSettingsService extends SMTService implements SMTIService
         		$this->getContext()->getLogger()->traceException( $ex);
         	}
         	
-        	if ( SMTOtuType::isOtu8KV2() )
+        	if (SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2())
         	{
 	        	try
 	        	{
