@@ -35,6 +35,7 @@ use app\admin\SMTOtuMode;
 use app\serviceshelper\otau\SMTRotauManager;
 use app\admin\SMTOtuType;
 use app\util\SMTInvalidValueException;
+use app\serviceshelper\otau\SMTDmuxManager;
 
 /**
  * Service to setup the OTU internal switch features and display its configuration.
@@ -113,6 +114,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     	    $configDetectSwitchDto->setOTAMPossible($this->getSwitchManager(TRUE)->isMolexSwitchPossible());
     	    $configDetectSwitchDto->setOTAMSwitch($this->getSwitchManager(TRUE)->hasMolexOSUDetected());
     	    $configDetectSwitchDto->setModuleCompatibleWithSwitch($this->getSwitchManager(TRUE)->isModuleCompatibleWithSwitch());
+    	    $configDetectSwitchDto->setModuleCompatibleWithDmuxSwitch(SMTDmuxManager::isDmuxSwitchSupported($this->getContext()) );
     	    $configDetectSwitchDto->setPortDistributorNumber($this->switchManager->getPortsDistributorNumber());
     	}
     	catch ( \Exception $e )
@@ -155,13 +157,14 @@ class SMTSwitchService extends SMTService implements SMTIService
     		$configDetectSwitchDto->setConfigured( $this->switchManager->getConfiguredSwitchDto() );
     		$configDetectSwitchDto->setDetected( $this->switchManager->getDetectedSwitchDto() );
     		$configDetectSwitchDto->setSwitchDifference( $this->switchManager->isDifference() );
-    		$configDetectSwitchDto->setDtssSwitch($this->switchManager->isDtssSwitch());
+    		$configDetectSwitchDto->setDtssSwitch($this->switchManager->isDtssSwitch());    		
     		$configDetectSwitchDto->setVirtualSwitch($this->switchManager->hasVirtualSwitch());
     		$configDetectSwitchDto->setSwitchDetectedHomogeneous($this->switchManager->isSwitchDetectedHomogeneous());
     		$configDetectSwitchDto->setIsOsxPowerOn($this->switchManager->getOsxPowerOn());
     		$configDetectSwitchDto->setOTAMPossible($this->switchManager->isMolexSwitchPossible());
     		$configDetectSwitchDto->setOTAMSwitch($this->switchManager->hasMolexOSUDetected());
     		$configDetectSwitchDto->setModuleCompatibleWithSwitch($this->switchManager->isModuleCompatibleWithSwitch());
+    		$configDetectSwitchDto->setModuleCompatibleWithDmuxSwitch(SMTDmuxManager::isDmuxSwitchSupported($this->getContext()) );
     		$configDetectSwitchDto->setPortDistributorNumber($this->switchManager->getPortsDistributorNumber());
     		if ( $configDetectSwitchDto->getPortDistributorNumber() > 0 )
     		{
@@ -289,6 +292,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     		$osxList->setIsBigTopology($this->switchManager->isBigTopology());
     		$osxList->setIsOsxPowerOn($this->switchManager->getOsxPowerOn());
     		$osxList->setOTAMPossible($this->switchManager->isMolexSwitchPossible());
+    		$osxList->setUOSPossible($this->switchManager->isUosSwitchPossible());
     		$osxList->setPortDistributorNumber($this->switchManager->getPortsDistributorNumber());
     		if ( $osxList->getPortDistributorNumber() > 0 )
     		{
@@ -301,14 +305,22 @@ class SMTSwitchService extends SMTService implements SMTIService
     			$hasMolexOsu = $this->switchManager->hasMolexOSUDetected();
     		    if (!$hasMolexOsu)
     		    {
-    		    	$hasJdsuOSU = $this->switchManager->hasJdsuOSU();
-    		    	if (!$hasJdsuOSU)
-    		    	{
-    		    		$hasMolexOsu= $this->switchManager->hasMolexOSU();
-    		    	}
+    		        $hasUos = $this->switchManager->hasUOSDetected();
+    		        if ( !$hasUos )
+    		        {    		        
+        		    	$hasJdsuOSU = $this->switchManager->hasJdsuOSU();
+        		    	if (!$hasJdsuOSU)
+        		    	{
+        		    		$hasMolexOsu= $this->switchManager->hasMolexOSU();
+        		    		if (!$hasMolexOsu)
+        		    		{
+        		    		    $hasUos = $this->switchManager->hasUOS();
+        		    		}
+        		    	}
+    		        }
     		    }
     		}
-    		$osxList->computeSwitchType($hasJdsuOSU, $hasMolexOsu);
+    		$osxList->computeSwitchType($hasJdsuOSU, $hasMolexOsu, $hasUos);
     	}
     	catch ( \Exception $e )
     	{
@@ -329,7 +341,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     	try
     	{
     		$otamScan = ($request_data != NULL && $request_data['otam'] != NULL)? filter_var( $request_data['otam'], FILTER_VALIDATE_BOOLEAN ) : FALSE;
-    		
+    		$hasUos = FALSE;
     		if ( $this->switchManager == NULL )
     		{
     			$this->switchManager = new SMTSwitchManager();
@@ -345,9 +357,14 @@ class SMTSwitchService extends SMTService implements SMTIService
     		$osxList->setIsBigTopology($this->switchManager->isBigTopology());
     		$osxList->setIsOsxPowerOn($this->switchManager->getOsxPowerOn());
     		$osxList->setOTAMPossible($this->switchManager->isMolexSwitchPossible());
+    		$osxList->setUOSPossible($this->switchManager->isUosSwitchPossible());
     		$osxList->setPortDistributorNumber($this->switchManager->getPortsDistributorNumber());
     		
-    		$osxList->computeSwitchType(!$otamScan, $otamScan);
+    		if (!$otamScan)
+    		{
+    		    $hasUos = $this->switchManager->hasUOSDetected();
+    		}
+    		$osxList->computeSwitchType(!$otamScan && !$hasUos, $otamScan, $hasUos);
     	}
     	catch ( \Exception $e )
     	{
@@ -499,7 +516,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     	$configDetectRotauDto= new SMTConfDetRotauDto();
     	try
     	{
-    		if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isOtu8KV2() || SMTOtuType::isCOtu() ) )
+    	    if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2()|| SMTOtuType::isCOtu() ) )
 	    	{
 	    		if ( $this->rotauManager== NULL )
 	    		{
@@ -532,7 +549,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     {
     	try
     	{
-    		if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isOtu8KV2() || SMTOtuType::isCOtu() ) )
+    	    if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2() || SMTOtuType::isCOtu() ) )
     		{
 	    		if ( $this->rotauManager== NULL )
 	    		{
@@ -565,7 +582,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     {
     	try
     	{
-    		if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isOtu8KV2() || SMTOtuType::isCOtu() ) )
+    	    if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2() || SMTOtuType::isCOtu() ) )
     		{
 	    		if ( $this->rotauManager== NULL )
 	    		{
@@ -597,7 +614,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     {
     	try
     	{
-    		if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isOtu8KV2() || SMTOtuType::isCOtu() ) )
+    	    if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2() || SMTOtuType::isCOtu() ) )
     		{
     			$configDetectRotauDto = SMTConfDetRotauDto::getInstance( $request_data );
     			if ( $configDetectRotauDto!= null)
@@ -638,6 +655,125 @@ class SMTSwitchService extends SMTService implements SMTIService
     	}
     }
     
+    /**
+     *
+     * @url GET /dmux/
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires user}
+     */
+    function fetchDmuxConfig()
+    {
+        $dmuxConf= new SMTConfDmuxDto();
+        try
+        {
+            if ( SMTOtuMode::isONMSi() )
+            {
+                $dmuxManager= new SMTDmuxManager();
+                $dmuxManager->setContext( $this->getContext() );
+                $dmuxManager->retrieve($dmuxConf);
+            }
+            else
+            {
+                new SMTInvalidValueException(SMTInvalidValueException::INVALID_VALUE, NULL, "DMUX", "not supported");
+            }
+        }
+        catch ( \Exception $e )
+        {
+            $this->handleException($e);
+        }
+        return $dmuxConf->getJsonData();
+    }
+    
+    /**
+     *
+     * @url POST /dmux
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires install}
+     */
+    function addDmux($request_data)
+    {
+        try
+        {
+            if ( SMTOtuMode::isONMSi() )
+            {
+                $dmuxManager= new SMTDmuxManager();
+                $dmuxManager->setContext( $this->getContext() );
+                $dmuxDto = SMTDmuxDto::getInstance( $request_data );
+                $dmuxManager->add($dmuxDto);
+            }
+            else
+            {
+                new SMTInvalidValueException(SMTInvalidValueException::INVALID_VALUE, NULL, "DMUX", "not supported");
+            }
+        }
+        catch ( \Exception $e )
+        {
+            $this->handleException($e);
+        }
+        return $this->fetchDmuxConfig();
+    }
+    
+    /**
+     *
+     * @url DELETE /dmux/{$dmuxId}
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires install}
+     */
+    function removeDmux($dmuxId)
+    {
+        try
+        {
+            if ( SMTOtuMode::isONMSi() )
+            {
+                $dmuxManager= new SMTDmuxManager();
+                $dmuxManager->setContext( $this->getContext() );
+                $dmuxManager->remove($dmuxId);
+            }
+            else
+            {
+                new SMTInvalidValueException(SMTInvalidValueException::INVALID_VALUE, NULL, "DMUX", "not supported");
+            }
+        }
+        catch ( \Exception $e )
+        {
+            $this->handleException($e);
+        }
+        return $this->fetchDmuxConfig();
+    }
+    
+    /**
+     *
+     * @url PUT /dmux
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires install}
+     */
+    function updateDmux($request_data)
+    {
+        try
+        {
+            if ( SMTOtuMode::isONMSi() )
+            {
+                $dmuxManager= new SMTDmuxManager();
+                $dmuxManager->setContext( $this->getContext() );
+                $dmuxConfDto = SMTConfDmuxDto::getInstance( $request_data );
+                $dmuxManager->update($dmuxConfDto);
+            }
+            else
+            {
+                new SMTInvalidValueException(SMTInvalidValueException::INVALID_VALUE, NULL, "DMUX", "not supported");
+            }
+        }
+        catch ( \Exception $e )
+        {
+            $this->handleException($e);
+        }
+        return $this->fetchDmuxConfig();
+    }
+    
     /**
      * @url GET /test/updateswitch
      */
