@@ -34,8 +34,12 @@ final class SMTLicenseList
 	const ULTRAFAST_MON='ULTRAFAST_MON';
 	const OTU_VPN='OTU_VPN';
 	const OTU_PAYG_PORT12='PAYG_PORT012';
+	const OTU_DUAL_ETH='DUAL_ETH';
 	const OTU_ONMSI_MONITORING='ONMSI_MONITORING';
 	const OTU_ONMSI_BUILD='ONMSI_BUILD';
+	const OTU_ONMSI_FA='ONMSI_FA';
+	const OTU_DWDM_SWITCH='DWDM_SWITCH';
+	const OTU_DWDM_NC_SWITCH='DWDM_NC_SWITCH';
 	
 	const OTU_OPTION_HIGH_SEC = 'HIGHSEC';
 	const OTU_OPTION_SSH_KEY_ACCESS = 'ACCESS';
@@ -50,8 +54,12 @@ final class SMTLicenseList
     const OTU_OPTION_ULTRAFAST_MON='ULTRAFAST_MON';
     const OTU_OPTION_VPN='OTU_VPN';
     const OTU_OPTION_PAYG_PORT12='PAYG_PORT012';
+    const OTU_OPTION_DUAL_ETH='DUAL_ETH';
     const OTU_OPTION_ONMSI_MONITORING='ONMSI_MON';
     const OTU_OPTION_ONMSI_BUILD='ONMSI_BUILD';
+    const OTU_OPTION_ONMSI_FA='ONMSI_FA';
+    const OTU_OPTION_DWDM_SWITCH='DWDM_SWITCH';
+    const OTU_OPTION_DWDM_NC_SWITCH='DWDM_NC_SWITCH';
     
 	const ISU_OPTION_SAA_L2_MONITORING = 'SMART_ACCESS_L2';
 	
@@ -77,8 +85,12 @@ final class SMTLicenseList
 	                                    self::OTU_OPTION_ULTRAFAST_MON=>self::ULTRAFAST_MON,
 	                                    self::OTU_OPTION_VPN=>self::OTU_VPN,
 	                                    self::OTU_OPTION_PAYG_PORT12=>self::OTU_PAYG_PORT12,
+	                                    self::OTU_OPTION_DUAL_ETH=>self::OTU_DUAL_ETH,
 	                                    self::OTU_OPTION_ONMSI_MONITORING=>self::OTU_ONMSI_MONITORING,
-	                                    self::OTU_OPTION_ONMSI_BUILD=>self::OTU_ONMSI_BUILD
+	                                    self::OTU_OPTION_ONMSI_BUILD=>self::OTU_ONMSI_BUILD,
+	                                    self::OTU_OPTION_ONMSI_FA=>self::OTU_ONMSI_FA,
+	                                    self::OTU_OPTION_DWDM_SWITCH=>self::OTU_DWDM_SWITCH,
+	                                    self::OTU_OPTION_DWDM_NC_SWITCH=>self::OTU_DWDM_NC_SWITCH
 	);
 	
 	static function getLicenseName( $scpiKey )
