@@ -17,6 +17,7 @@ use app\services\maintenance\SMTBackupDto;
 
 use app\util\SMTIOException;
 
+use app\admin\SMTOtuType;
 use app\parser\SMTOtuApi;
 
 use app\serviceshelper\SMTServiceHelper;
@@ -30,10 +31,19 @@ use app\util\SMTLogger;
  */
 class SMTOtuBackupRestore extends SMTServiceHelper
 {
-    const OTU_BACKUP_DIR = "/acterna/user/harddisk/";
     const OTU_BACKUP_NAME_PREFIX = "smartotu-backup-";
     const OTU_BACKUP_NAME_SUFFIX = ".tar.gz";
-    const OTU_BACKUP_NAME_EMPTY_SERIAL_NUMBER = "00000";
+    const OTU_BACKUP_NAME_EMPTY_SERIAL_NUMBER = "00000";    
+    
+    /**
+     * Backup full file path on disk
+     *
+     *
+     */
+    static function getBackupDir()
+    {
+        return '/user/harddisk/';
+    }
     
     /**
      * Create a backup of SmartOTU configuration and monitoring on OTU disk and return the backup full path name.
@@ -154,7 +164,7 @@ class SMTOtuBackupRestore extends SMTServiceHelper
     	}
     	
     	//retrieve file name
-   		$resultArray = glob( self::OTU_BACKUP_DIR.$backupName );
+    	$resultArray = glob( self::getBackupDir().$backupName );
     
 		//first file is the file to download; if glob fails, returns false
 		if ( $resultArray != FALSE && !empty( $resultArray ) )
@@ -175,7 +185,7 @@ class SMTOtuBackupRestore extends SMTServiceHelper
     	$currentBackupName = NULL;        
     	
     	//retrieve file name
-    	$files = glob( self::OTU_BACKUP_DIR.self::OTU_BACKUP_NAME_PREFIX."*".self::OTU_BACKUP_NAME_SUFFIX );    	
+    	$files = glob( self::getBackupDir().self::OTU_BACKUP_NAME_PREFIX."*".self::OTU_BACKUP_NAME_SUFFIX );    	
     	
     	//search last backup file
     	if ( $files != FALSE && !empty( $files ) )
