@@ -45,17 +45,19 @@ class SMTUpgrade extends SMTServiceHelper
     
     const OTU_RELEASE_NAME = "*otu-8kv2*.tar*";
     
-    const COTU_RELEASE_NAME = "*5000*.tar*"; 
+    const COTU_RELEASE_NAME = "*5000*.tar*";
+    
+    const OTH_RELEASE_NAME = "fth*.tar*"; 
 
     const OTU_RELEASE_CURRENT_DIR = "/otu/release/current/";
     
     const OTU_PATCH_CURRENT_DIR = "/otu/release/patch/";
     
-    const OTU_UPGRADE_VERSION_COMMAND = "export DETACHED=1; sudo /sbin/start_upgrade_otu.sh --tar %s --upgradeversion";
+    const OTU_UPGRADE_VERSION_COMMAND = 'export DETACHED=1; sudo /sbin/start_upgrade_otu.sh --tar "%s" --upgradeversion';
     
-    const OTU_UPGRADE_NORMAL_FS_COMMAND = 'sudo /sbin/start_upgrade_otu.sh --tar %s --short --nodet';
+    const OTU_UPGRADE_NORMAL_FS_COMMAND = 'sudo /sbin/start_upgrade_otu.sh --tar "%s" --short --nodet';
     
-    const OTU_UPGRADE_RESCUE_FS_COMMAND = 'sudo /sbin/start_upgrade_otu.sh --tar %s --target rescue --index rescue --nomd5 --nodet';
+    const OTU_UPGRADE_RESCUE_FS_COMMAND = 'sudo /sbin/start_upgrade_otu.sh --tar "%s" --target rescue --index rescue --nomd5 --nodet';
     
     const DEFAULT_MAX_RELEASE_COUNT = 2;
     
@@ -70,7 +72,7 @@ class SMTUpgrade extends SMTServiceHelper
         $count = 0;
         
         //retrieve file name
-        $resultArray = (SMTOtuType::isCOtu_EOTDRV2())? glob( self::OTU_CURRENT_UPGRADE_DIR.self::COTU_RELEASE_NAME) : glob( self::OTU_CURRENT_UPGRADE_DIR.self::OTU_RELEASE_NAME );
+        $resultArray = (SMTOtuType::isCOtu_EOTDRV2())? glob( self::OTU_CURRENT_UPGRADE_DIR.self::COTU_RELEASE_NAME) : ((SMTOtuType::isOTH())? glob( self::OTU_CURRENT_UPGRADE_DIR.self::OTH_RELEASE_NAME) : glob( self::OTU_CURRENT_UPGRADE_DIR.self::OTU_RELEASE_NAME ) );
         if ( $resultArray != FALSE && !empty( $resultArray ) )
         {
             $upgradeFiles = array();
@@ -284,7 +286,7 @@ class SMTUpgrade extends SMTServiceHelper
     public static function getCurrentDuplicationProgressLog( SMTUpgradeDto $upgradeDto, SMTContext $context )
     {
     	//check if a duplication progress file is present:
-    	if ( (SMTOtuType::isCOtu_EOTDRV2()) && file_exists( self::OTU_DUPLICATION_PROGRESS_FILE ) )
+        if ( (SMTOtuType::isCOtu_EOTDRV2() || SMTOtuType::isOTH() ) && file_exists( self::OTU_DUPLICATION_PROGRESS_FILE ) )
     	{
     		$file = fopen( self::OTU_DUPLICATION_PROGRESS_FILE,'r');
     		$row = 0;
