@@ -71,10 +71,10 @@ abstract class SMTRwDto extends SMTDto
      *
      * @throws InvalidArgumentException if the dto class doesn't exist.
      */
-    static function getInstance( $dtoClassName, array $json_array )
-    {
-    	return self::forge( $dtoClassName, $json_array );
-    }
+//     static function getInstance( $dtoClassName, array $json_array )
+//     {
+//     	return self::forge( $dtoClassName, $json_array );
+//     }
     
     /**
      * cast stdClass object to a Dto. Recursively cast object properties if they are dto.
