@@ -1,6 +1,8 @@
 #!/bin/bash
 #set -x
 
+# SCRIPT USED FOR YOCTO
+
 function GetFreePort
    {
    local Port
@@ -35,11 +37,11 @@ function Authentication
    #Obtenir la configuration du Proxy dans System Setup sauf dans le cas usb o ce n'est pas utile (connexion directe internet 3G)
    if [ "$media" != "usbg" ]
       then
-      UseProxy=$(echo "*rem;SYST:PROXY:USE?" | nc -w2 127.0.0.1 8000)
+      UseProxy=$(scpi "SYST:PROXY:USE?")
       
       case $UseProxy in
          MAN)
-            Proxy=$(echo "*rem;SYST:PROXY:ADDR?" | nc -w2 127.0.0.1 8000)
+            Proxy=$(scpi "SYST:PROXY:ADDR?")
             if [ "$Proxy" != "" ]
                then
                ViaProxy="-p $Proxy"
@@ -47,7 +49,7 @@ function Authentication
             ;;
          
          PAC)
-            ProxyPac=$(echo "*rem;SYST:PROXY:PAC?" | nc -w2 127.0.0.1 8000)
+            ProxyPac=$(scpi "SYST:PROXY:PAC?")
             if [ "$ProxyPac" != "" ]
                then
                Proxy=$(get_proxy_from_pac $ProxyPac $SP_SSH1 $SP_SSH1 | cut -f2 -d "=")
@@ -257,9 +259,9 @@ if [ "$Connection_Type" != "DISCONNECT" ]
          if [ "$RetCode" == 0 ]
             then
             #test si SAA est dmarr explicitement sur la base distante
-            StatusSAA=$(echo "*rem;SYST:SAA?" | nc -w2 127.0.0.1 18000  | tr -d " ")
+            StatusSAA=$(scpi -p 18000 "SYST:SAA?" | tr -d " ")
             #test la licence valide sur la base distante
-            M2mLinkLicence=$(echo "*rem;PROC:LIC:STAT? \"Anywhere\",\"SMART_ACCESS_L2\"" | nc -w2 127.0.0.1 18000  | tr -d " ")
+            M2mLinkLicence=$(scpi -p 18000 "PROC:LIC:STAT? \"Anywhere\",\"SMART_ACCESS_L2\"" | tr -d " ")
             if [ "$Connection_Type" != "CONNECT_IP" -a "$StatusSAA" == "DISCONNECTED" ]
                then
                RetCode=255
@@ -312,7 +314,7 @@ if [ "$Connection_Type" != "DISCONNECT" ]
                      do
                         sleep 10
                         done
-                        echo  "*rem;ISU:M2MLINK OFF"  | nc -w2 127.0.0.1 8000	    
+                        scpi "ISU:M2MLINK OFF"
                   ) &)&
                fi
                #activation du datalink sur l'appareil "esclave"
@@ -320,10 +322,10 @@ if [ "$Connection_Type" != "DISCONNECT" ]
                   then
                   # transmission du magic number
                   scp -P $PortSsh $Anywhere_Or_Ip_File local:/tmp/anywhere_remote.nbr
-                  echo "*rem;mod:func:sel boths,base,\"M2MLINK\",on" | nc -w2 127.0.0.1 18000
+                  scpi -p 18000 "mod:func:sel boths,base,\"M2MLINK\",on"
                fi
                # lecture identite de l'appareil esclave
-               MtsIdent=$(echo "*rem;*idn?" | nc -w2 127.0.0.1 18000  | tr -d " " )
+               MtsIdent=$(scpi -p 18000 "*idn?" | tr -d " " )
                MtsName=$(echo $MtsIdent | cut -d ',' -f2)
                MtsSN=$(echo $MtsIdent | cut -d ',' -f3)
                echo -en "*rem\nprocess:warning \"\",\"Connected to $MtsName S/N $MtsSN\", INFO, 0,\"\",\"\",\"Press any key to continue\"\n" >/dev/tcp/127.0.0.1/8000
@@ -366,7 +368,7 @@ else
    #arret du processus detach qui surveille la connexion entre deux bases quand elle tombe.
    kill $(ps aux | grep client_connection_script | grep -v grep | grep -v $$ | tr -s ' ' | cut -d ' ' -f2 )
    # arret du datalink sur l'appareil "esclave"
-   echo "*rem;ISU:M2MLINK OFF" | nc -w2 127.0.0.1 18000
+   scpi -p 18000 "ISU:M2MLINK OFF"
      
    fusermount -u -z /tmp/slaveharddisk
    fusermount -u -z /tmp/slavedisk
