@@ -1,5 +1,5 @@
-#! /usr/bin/env python
-from pyPdf import PdfFileWriter, PdfFileReader
+#! /usr/bin/python3
+from PyPDF3 import PdfFileWriter, PdfFileReader
 
 import sys
 
@@ -7,7 +7,7 @@ import sys
 # pdf_join.py <output_pdf_file> <input_pdf_file1> <input_pdf_file2> <input_pdf_file3> ...etc
 
 if len(sys.argv) < 3:
-    print 'error - missing arguments.'
+    print('error - missing arguments.')
     sys.exit(1)
 
 output = PdfFileWriter()
@@ -19,17 +19,17 @@ try:
     pdfList = list()
 
     for fileName in sys.argv:
-        pdfReader = PdfFileReader(file(fileName, 'rb'))
+        pdfReader = PdfFileReader(open(fileName, 'rb'))
         for page in range(pdfReader.getNumPages()):
             output.addPage(pdfReader.getPage(page))
 
         pdfList.append(pdfReader)
 
-    outputStream = file(outputFilename , "wb")
+    outputStream = open(outputFilename , "wb")
     output.write(outputStream)
     outputStream.close()
-except Exception, e:
-    print e
+except Exception as e:
+    print(e)
     sys.exit(1)
 
 sys.exit(0)
