@@ -8,6 +8,8 @@ import select
 import evdev as ev
 from time import sleep
 
+DEBUG = False
+
 def get_event_device_by_name(name):
     for f in os.listdir("/sys/class/input"):
         if f.startswith("event"):
@@ -61,6 +63,7 @@ class InputDevice(threading.Thread):
         self.__queue = queue.Queue(10)
         self.__posx = 0
         self.__posy = 0
+        self.__sync = False
         self.__pos = None
         self.__absinfo = {}
         threading.Thread.__init__(self)
@@ -72,7 +75,7 @@ class InputDevice(threading.Thread):
             for caps in capa[3]:
                 self.__absinfo[caps[0]] = caps[1]
         while not self.__exit:
-            r, w, e = select.select([dev.fileno()], [], [], 1)
+            r, w, es = select.select([dev.fileno()], [], [], 1)
             if not dev.fileno() in r:
                 if self.__timeout is not None:
                     self.__timeout -= 1
@@ -80,9 +83,12 @@ class InputDevice(threading.Thread):
                         self.__queue.put((None,))
                 continue
             event = dev.read_one()
+            if(DEBUG): print("event --> %s "%(event), end='')
             if self.__exit:
                 break
+            e = ev.categorize(event)
             if event.type == ev.ecodes.EV_KEY:
+                if(DEBUG): print("EV_KEY")
                 if event.value == 1:
                     self.__stack.append(event.code)
                     self.__depth += 1
@@ -98,7 +104,7 @@ class InputDevice(threading.Thread):
                             self.__queue.put(tuple(self.__stack))
                             self.__stack.clear()
             elif event.type == ev.ecodes.EV_ABS:
-                e = ev.categorize(event)
+                if(DEBUG): print("EV_ABS")
                 if type(e) == ev.events.AbsEvent:
                     if e.event.code in (ev.ecodes.ABS_X, ev.ecodes.ABS_MT_POSITION_X):
                         if self.__calibration is not None:
@@ -113,7 +119,21 @@ class InputDevice(threading.Thread):
                 else:
                     print("OTHER EVENT")
             elif event.type == ev.ecodes.EV_SYN:
+                if(DEBUG): print("EV_SYN (%i %i)"%(self.__posx, self.__posy))
                 self.__pos = (self.__posx, self.__posy)
+                if e.event.code != ev.ecodes.SYN_MT_REPORT:
+                    continue
+                if self.__posx + self.__posy == 0:
+                    self.__sync = False
+                    # Release
+                else:
+                    if not self.__sync:
+                        self.__queue.put( (ev.ecodes.BTN_TOUCH, (self.__pos)) )
+                        self.__sync = True
+                        if(DEBUG): print("TOUCH %i %i"%(self.__pos[0],self.__pos[1]))
+                    self.__posx = 0
+                    self.__posy = 0
+
                 self.__queue.put( (ev.ecodes.KEY_MOVE, (self.__pos)) )
             else:
                 print("OTHER EVENT")
