@@ -1,7 +1,7 @@
 from viavi.evm import *
 from viavi.diag import *
-from jdsu.cal.calib import *
-from jdsu.mts.blockutils import mount_cal, umount_cal
+from viavi.mts.calib import *
+from viavi.mts.blockutils import mount_cal, umount_cal
 import os
 from shutil import rmtree
 
