@@ -1,5 +1,5 @@
-from jdsu.evm import *
-from jdsu.diag import *
+from viavi.evm import *
+from viavi.diag import *
 import subprocess
 import sys
 import time
