@@ -1,5 +1,5 @@
-from jdsu.evm import *
-from jdsu.diag import DIAG
+from viavi.evm import *
+from viavi.diag import DIAG
 
 
 @DIAG("Return Bist version")
